An ergonomic, high-level Rust wrapper for the Windows.Graphics.Capture API.
This crate provides safe and idiomatic Rust bindings for screen and window capture functionality on Windows.
Repository: GitHub
Re-exports
pub use settings::*;pub use frame::*;pub use capture::*;pub use error::*;pub use capabilities::*;
Modules
Functions
- new_
item_ from_ hwnd - Creates a new
GraphicsCaptureItemfrom a window handle. - new_
item_ from_ monitor - Creates a new
GraphicsCaptureItemfrom a monitor handle. - new_
item_ with_ picker - Presents a picker UI to allow the user to select a window or monitor for graphics capture.